#Load all necessary packages

library(phyloseq)
library(vegan)
library(ggplot2)
library(dplyr)
library(tidyr)
library(ggpubr)
library(microbiome)
library(ape)
library(tidyverse)
library(indicspecies)
library(ggVennDiagram)
library(ggvenn) 
library(grid) 


#Converted our .qza files to appropriate formats and exported to local computer

#Objective 1 - Create 4 subsets of metadata
#Filter to smoker, non-smoker, healthy, abnormal

#load all the necessary data files
metafp <- "colombia_metadata.txt"
meta <- read_delim(metafp, delim="\t")

otufp <- "noMC-feature-table.txt"
otu <- read_delim(file = otufp, delim="\t", skip=1)

taxfp <- "taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")

phylotreefp <- "tree.nwk"
phylotree <- read.tree(phylotreefp)

####create a phyloseq object####
#creating a phyloseq object
metafp <- "colombia_metadata.txt"
meta_data <- read_delim(metafp, delim="\t")

otufp <- "noMC-feature-table.txt"
otu_table <- read_delim(file = otufp, delim="\t", skip=1)

taxfp <- "taxonomy.tsv"
taxonomy <- read_delim(taxfp, delim="\t")

phylotreefp <- "tree.nwk"
phylotree <- read.tree(phylotreefp)

#Format OTU table
otu_mat <- as.matrix(otu_table[,-1])
rownames(otu_mat) <- otu_table$`#OTU ID`
OTU <- otu_table(otu_mat, taxa_are_rows = TRUE) 

#Format metadata
samp_df <- as.data.frame(meta_data[,-1])
rownames(samp_df)<- meta_data$`#SampleID`
SAMP <- sample_data(samp_df)

#Format taxonomy
tax_mat <- taxonomy %>% select(-Confidence)%>%
  separate(col=Taxon, sep="; "
           , into = c("Domain","Phylum","Class","Order","Family","Genus","Species")) %>%
  as.matrix()

tax_mat <- tax_mat[,-1]
rownames(tax_mat) <- taxonomy$`Feature ID`
TAX <- tax_table(tax_mat)

#Merge all
colombia <- phyloseq(OTU, SAMP, TAX, phylotree)
otu_table(colombia)
sample_data(colombia)
tax_table(colombia)
phy_tree(colombia)

#alpha rarefaction depth determined using QIIME2 view 
colombia_rare <- rarefy_even_depth(colombia, rngseed = 1, sample.size = 20291)

#Filter phyloseq based on metadata
#1) smoker only
colombia_smoker <- subset_samples(colombia_rare, smoker == "Yes")

#2) non-smoker only
colombia_non_smoker <- subset_samples(colombia_rare, smoker == "No")

#3) healthy only
colombia_healthy <- subset_samples(colombia_rare, Cardiometabolic_status == "Healthy")

#4) abnormal only
colombia_abnormal <- subset_samples(colombia_rare, Cardiometabolic_status == "Abnormal")

# Creating relative-count phyloseq objects for the subsetted groups
colombia_relative <- transform_sample_counts(colombia_rare, fun=function(x) x/sum(x))

colombia_smoker_relative <- transform_sample_counts(colombia_smoker, fun=function(x) x/sum(x))

colombia_non_smoker_relative <- transform_sample_counts(colombia_non_smoker, fun=function(x) x/sum(x))

colombia_healthy_relative <- transform_sample_counts(colombia_healthy, fun=function(x) x/sum(x))

colombia_abnormal_relative <- transform_sample_counts(colombia_abnormal, fun=function(x) x/sum(x))

# Create 2-way venn diagrams for each of the metadata category comparisons.
# Compare the different prevalence values for the same detection threshold. 
# Subset both ways, by smoking status first or cardiometabolic status first.

####Core Microbiome Analysis####

#smokers
Healthy_smoker_phyloseq <- subset_samples(colombia_smoker_relative, Cardiometabolic_status=="Healthy")
Abnormal_smoker_phyloseq <- subset_samples(colombia_smoker_relative, Cardiometabolic_status=="Abnormal")

Healthy_smoker_core <- core_members(Healthy_smoker_phyloseq, detection=0.001, prevalence=0.5)
Abnormal_smoker_core <- core_members(Abnormal_smoker_phyloseq, detection=0.001, prevalence=0.5)

ggVennDiagram(x=list(Healthy_smoker_core, Abnormal_smoker_core)) +
  scale_color_brewer(palette = ("Set1")) +
  scale_fill_distiller(palette = "YlGnBu", direction = 1)

#non smokers
Healthy_nonsmoker_phyloseq <- subset_samples(colombia_non_smoker_relative, Cardiometabolic_status=="Healthy")
Abnormal_nonsmoker_phyloseq <- subset_samples(colombia_non_smoker_relative, Cardiometabolic_status=="Abnormal")

Healthy_nonsmoker_core <- core_members(Healthy_nonsmoker_phyloseq, detection=0.001, prevalence=0.5)
Abnormal_nonsmoker_core <- core_members(Abnormal_nonsmoker_phyloseq, detection=0.001, prevalence=0.5)

ggVennDiagram(x=list(Healthy_nonsmoker_core, Abnormal_nonsmoker_core))+
  scale_color_brewer(palette = ("Set1")) +
  scale_fill_distiller(palette = "YlGnBu", direction = 1)

#healthy
Smoker_healthy_phyloseq <- subset_samples(colombia_healthy_relative, smoker=="Yes")
Non_smoker_healthy_phyloseq <- subset_samples(colombia_healthy_relative, smoker=="No")

Smoker_healthy_core <- core_members(Smoker_healthy_phyloseq, detection=0.001, prevalence=0.5)
Nonsmoker_healthy_core <- core_members(Non_smoker_healthy_phyloseq, detection=0.001, prevalence=0.5)

w <- c("Smoker", "Non-smoker")
ggVennDiagram(x=list(Smoker_healthy_core, Nonsmoker_healthy_core), set_names(w), label_size = 6, set_size = 6)+
  scale_color_brewer(palette = ("Set1")) +
  scale_fill_distiller(palette = "YlGnBu", direction = 1)

#abnormal 
Smoker_abnormal_phyloseq <- subset_samples(colombia_abnormal_relative, smoker=="Yes")
Non_smoker_abnormal_phyloseq <- subset_samples(colombia_abnormal_relative, smoker=="No")

Smoker_abnormal_core <- core_members(Smoker_abnormal_phyloseq, detection=0.001, prevalence=0.5)
Nonsmoker_abnormal_core <- core_members(Non_smoker_abnormal_phyloseq, detection=0.001, prevalence=0.5)

v <- c("Smoker", "Non-smoker")
ggVennDiagram(x=list(Smoker_abnormal_core, Nonsmoker_abnormal_core), set_names(v), label_size = 6, set_size = 6)+
  scale_color_brewer(palette = ("Set1")) +
  scale_fill_distiller(palette = "YlGnBu", direction = 1)



# different prevalence --> 0.6
#smokers
Healthy_smoker_core2 <- core_members(Healthy_smoker_phyloseq, detection=0.001, prevalence=0.6)
Abnormal_smoker_core2 <- core_members(Abnormal_smoker_phyloseq, detection=0.001, prevalence=0.6)

ggVennDiagram(x=list(Healthy_smoker_core2, Abnormal_smoker_core2))

#non smokers
Healthy_nonsmoker_core2 <- core_members(Healthy_nonsmoker_phyloseq, detection=0.001, prevalence=0.6)
Abnormal_nonsmoker_core2 <- core_members(Abnormal_nonsmoker_phyloseq, detection=0.001, prevalence=0.6)

ggVennDiagram(x=list(Healthy_nonsmoker_core2, Abnormal_nonsmoker_core2))

#healthy
Smoker_healthy_core2 <- core_members(Smoker_healthy_phyloseq, detection=0.001, prevalence=0.6)
Nonsmoker_healthy_core2 <- core_members(Non_smoker_healthy_phyloseq, detection=0.001, prevalence=0.6)

ggVennDiagram(x=list(Smoker_healthy_core2, Nonsmoker_healthy_core2))

#abnormal 
Smoker_abnormal_core2 <- core_members(Smoker_abnormal_phyloseq, detection=0.001, prevalence=0.6)
Nonsmoker_abnormal_core2 <- core_members(Non_smoker_abnormal_phyloseq, detection=0.001, prevalence=0.6)

ggVennDiagram(x=list(Smoker_abnormal_core2, Nonsmoker_abnormal_core2))


# different prevalence --> 0.75
#smokers
Healthy_smoker_core3 <- core_members(Healthy_smoker_phyloseq, detection=0.001, prevalence=0.75)
Abnormal_smoker_core3 <- core_members(Abnormal_smoker_phyloseq, detection=0.001, prevalence=0.75)

ggVennDiagram(x=list(Healthy_smoker_core3, Abnormal_smoker_core3))

#non smokers
Healthy_nonsmoker_core3 <- core_members(Healthy_nonsmoker_phyloseq, detection=0.001, prevalence=0.75)
Abnormal_nonsmoker_core3 <- core_members(Abnormal_nonsmoker_phyloseq, detection=0.001, prevalence=0.75)

ggVennDiagram(x=list(Healthy_nonsmoker_core3, Abnormal_nonsmoker_core3))

#healthy
Smoker_healthy_core3 <- core_members(Smoker_healthy_phyloseq, detection=0.001, prevalence=0.75)
Nonsmoker_healthy_core3 <- core_members(Non_smoker_healthy_phyloseq, detection=0.001, prevalence=0.75)

ggVennDiagram(x=list(Smoker_healthy_core3, Nonsmoker_healthy_core3))

#abnormal 
Smoker_abnormal_core3 <- core_members(Smoker_abnormal_phyloseq, detection=0.001, prevalence=0.75)
Nonsmoker_abnormal_core3 <- core_members(Non_smoker_abnormal_phyloseq, detection=0.001, prevalence=0.75)

ggVennDiagram(x=list(Smoker_abnormal_core3, Nonsmoker_abnormal_core3))


####4-way venn diagram#### 
# First subset by Cardiometabolic status and then by smoker/nonsmoker identification

y <- list(Smoker_healthy_core, Nonsmoker_healthy_core, Smoker_abnormal_core, Nonsmoker_abnormal_core)
x <- c("Healthy Smoker", "Healthy Non-smoker", "Abnormal Smoker", "Abnormal Non-smoker")

gg4venn <- ggVennDiagram(y, set_names((x)), label = "count", set_size = 4.5, label_size = 6)  +
  scale_x_continuous(expand = expansion(mult = .3)) +
  scale_color_brewer(palette = ("Set1")) +
  scale_fill_distiller(palette = "YlGnBu", direction = 1)
gg4venn


#### Identifying the 8 ASVs absent from the abnormal smokers ####
total_res = append(Healthy_nonsmoker_core,Healthy_smoker_core)
total_res = append(total_res,Abnormal_smoker_core)
total_res = append(total_res,Abnormal_nonsmoker_core)
total_res = data.frame(total_res)

names = as.matrix(unique(total_res))
df1 = list()
df2 = list()
df3 = list()
for (i in names){
  if (i %in% Healthy_smoker_core & i %in% Abnormal_nonsmoker_core & i %in% Healthy_nonsmoker_core){
    df1[[i]] = i
    if(i %in% Abnormal_smoker_core){
      df2[[i]] = i
    } else{
      df3[[i]] = i
      
      
    }
  }
  
  
  
}
taxa_info = data.frame(tax_table(colombia_rare))
taxa_info$ASV = rownames(taxa_info)
df3 = data.frame(ASV = df3)
df3$ASV = as.character(df3$ASV)
unique_abnormal_smoking = inner_join(taxa_info, df3, by = "ASV")
write.csv(unique_abnormal_smoking, file = "core ASVs unique to Abnormal Smoking.csv")


