#Load all necessary packages
library(phyloseq)
library(vegan)
library(ggplot2)
library(dplyr)
library(tidyr)
library(microbiome)
library(ape)
library(tidyverse)
library(indicspecies)
library(ggVennDiagram)
library(DESeq2)

setwd("C:/Users/clee41/OneDrive - UBC/Desktop/GradWork/Classes/TAMICB475/team repos/MDMA/MICB475_Group_12/Alpha beta diversity")
#Converted our .qza files to appropriate formats and exported to local computer

#Objective 1 - Create 4 subsets of metadata
#Filter to smoker, non-smoker, healthy, abnormal

#load all the necessary data files
metafp <- "colombia_metadata.txt"
meta <- read_delim(metafp, delim="\t")

otufp <- "noMC-feature-table.txt"
otu <- read_delim(file = otufp, delim="\t", skip=1)

taxfp <- "taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")

phylotreefp <- "tree.nwk"
phylotree <- read.tree(phylotreefp)

#create a phyloseq object

#creating a phyloseq object
metafp <- "colombia_metadata.txt"
meta_data <- read_delim(metafp, delim="\t")

otufp <- "noMC-feature-table.txt"
otu_table <- read_delim(file = otufp, delim="\t", skip=1)

taxfp <- "taxonomy.tsv"
taxonomy <- read_delim(taxfp, delim="\t")

phylotreefp <- "tree.nwk"
phylotree <- read.tree(phylotreefp)

#Format OTU table
otu_mat <- as.matrix(otu_table[,-1])
rownames(otu_mat) <- otu_table$`#OTU ID`
OTU <- otu_table(otu_mat, taxa_are_rows = TRUE) 

#Format metadata
samp_df <- as.data.frame(meta_data[,-1])
rownames(samp_df)<- meta_data$`#SampleID`
SAMP <- sample_data(samp_df)

#Format taxonomy
tax_mat <- taxonomy %>% select(-Confidence)%>%
  separate(col=Taxon, sep="; "
           , into = c("Domain","Phylum","Class","Order","Family","Genus","Species")) %>%
  as.matrix()

tax_mat <- tax_mat[,-1]
rownames(tax_mat) <- taxonomy$`Feature ID`
TAX <- tax_table(tax_mat)

#Merge all
colombia <- phyloseq(OTU, SAMP, TAX, phylotree)
otu_table(colombia)
sample_data(colombia)
tax_table(colombia)
phy_tree(colombia)


#Filter phyloseq based on metadata
#1) smoker only
colombia_smoker <- subset_samples(colombia, smoker == "Yes")

#2) non-smoker only
colombia_non_smoker <- subset_samples(colombia, smoker == "No")

#3) healthy only
colombia_healthy <- subset_samples(colombia, Cardiometabolic_status == "Healthy")

#4) abnormal only
colombia_abnormal <- subset_samples(colombia, Cardiometabolic_status == "Abnormal")


my_colors <- c("blue", "red", "green", "purple", "orange", "brown", "pink","yellow", "skyblue")






#### DESeq Columbia Smoker ####
colombia_smoker_deseq <- phyloseq_to_deseq2(colombia_smoker, ~Cardiometabolic_status)
DESEQ_colombia_smoker <- DESeq(colombia_smoker_deseq)
results_smoker <- results(DESEQ_colombia_smoker, tidy=TRUE)
View(results_smoker)

## Make variable to color by whether it is significant + large change
results_smoker %>%
  mutate(significant = padj<0.01 & abs(log2FoldChange)>2) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant))

# To get table of results
sigASVs_smoker <- results_smoker %>% 
  filter(padj<0.01 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)
View(sigASVs_smoker)

# Get only asv names
sigASVs_smoker_vec <- sigASVs_smoker %>%
  pull(ASV)

# Prune phyloseq file
Colombia_smoker_DESeq <- prune_taxa(sigASVs_smoker_vec,colombia)
sigASVs_smoker <- tax_table(Colombia_smoker_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_smoker) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

ggplot(sigASVs_smoker) +
  geom_bar(aes(x=Genus, y=log2FoldChange), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(angle=90, hjust=1, vjust=0.5))


#### DESeq Columbia Non-Smoker ####
## NOTE: If you get a zeros error, then you need to add '1' count to all reads
Colombia_nonsmoker_plus1 <- transform_sample_counts(colombia_non_smoker, function(x) x+1)
colombia_non_smoker_deseq <- phyloseq_to_deseq2(Colombia_nonsmoker_plus1, ~Cardiometabolic_status)
DESEQ_colombia_non_smoker <- DESeq(colombia_non_smoker_deseq)
results_non_smoker <- results(DESEQ_colombia_non_smoker, tidy=TRUE)
View(results_non_smoker)


## Make variable to color by whether it is significant + large change
results_non_smoker %>%
  mutate(significant = padj<0.01 & abs(log2FoldChange)>2) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant))

# To get table of results
sigASVs_non_smoker <- results_non_smoker %>% 
  filter(padj<0.01 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)
View(sigASVs_non_smoker)

# Get only asv names
sigASVs_non_smoker_vec <- sigASVs_non_smoker %>%
  pull(ASV)

# Prune phyloseq file
Colombia_non_smoker_DESeq <- prune_taxa(sigASVs_non_smoker_vec,colombia)
sigASVs_non_smoker <- tax_table(Colombia_non_smoker_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_non_smoker) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

ggplot(sigASVs_non_smoker) +
  geom_bar(aes(x=Genus, y=log2FoldChange), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(angle=90, hjust=1, vjust=0.5))





#### DESeq Columbia Healthy ####
Colombia_healthy_plus1 <- transform_sample_counts(colombia_healthy, function(x) x+1)
colombia_healthy_deseq <- phyloseq_to_deseq2(Colombia_healthy_plus1, ~relevel(smoker, ref = "No"))
DESEQ_colombia_healthy <- DESeq(colombia_healthy_deseq)
results_healthy <- results(DESEQ_colombia_healthy, tidy=TRUE)
View(results_healthy)


## Make variable to color by whether it is significant + large change
results_healthy %>%
  mutate(significant = padj<0.01 & abs(log2FoldChange)>2) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant)) +
  scale_y_continuous(limits=c(0, 15)) + scale_x_continuous(limits=c(-8, 8)) +
  labs(x = "Log2 Fold Change", y = "-Log10 (padj)") + labs(title = "Reduced Overall Differential Abundance in Smokers vs. Non-smokers (Healthy)", size = 20)+
  theme(axis.title = element_text(size = 30))


# To get table of results
sigASVs_healthy <- results_healthy %>% 
  filter(padj<0.01 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)
View(sigASVs_healthy)

# Get only asv names
sigASVs_healthy_vec <- sigASVs_healthy %>%
  pull(ASV)

# Prune phyloseq file
Colombia_healthy_DESeq <- prune_taxa(sigASVs_healthy_vec,colombia)
sigASVs_healthy <- tax_table(Colombia_healthy_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_healthy) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

# Colored version based on Phylum
ggplot(sigASVs_healthy, aes(x=Genus, y=log2FoldChange, fill=Phylum)) +
  geom_bar(stat="identity") +
  geom_errorbar(aes(ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  scale_fill_manual(values=my_colors) +
  theme(axis.text.x=element_text(angle=90, hjust=1, vjust=0.5)) +
  scale_y_continuous(limits=c(-8, 8)) +
  labs(y = "Log2 Fold Change") + labs(title = "Smoker vs Non-smoker Differentially Expressed Genus in the Gut Microbiome (Healthy)", size = 20)+
  theme(axis.title = element_text(size = 30))


#### DESeq Columbia Abnormal ####
Colombia_abnormal_plus1 <- transform_sample_counts(colombia_abnormal, function(x) x+1)
colombia_abnormal_deseq <- phyloseq_to_deseq2(Colombia_abnormal_plus1, ~relevel(smoker, ref = "No"))
DESEQ_colombia_abnormal <- DESeq(colombia_abnormal_deseq)
results_abnormal <- results(DESEQ_colombia_abnormal, tidy=TRUE)
View(results_abnormal)

## Make variable to color by whether it is significant + large change
results_abnormal %>%
  mutate(significant = padj<0.01 & abs(log2FoldChange)>2) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant)) +
  scale_y_continuous(limits=c(0, 15)) + scale_x_continuous(limits=c(-8, 8)) +
  labs(x = "Log2 Fold Change", y = "-Log10 (padj)") + labs(title = "Reduced Overall Differential Abundance in Smokers vs. Non-smokers (Abnormal)", size = 20)+
  theme(axis.title = element_text(size = 30))

# To get table of results
sigASVs_abnormal <- results_abnormal %>% 
  filter(padj<0.01 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)
View(sigASVs_abnormal)

# Get only asv names
sigASVs_abnormal_vec <- sigASVs_abnormal %>%
  pull(ASV)

# Prune phyloseq file
Colombia_abnormal_DESeq <- prune_taxa(sigASVs_abnormal_vec,colombia)
sigASVs_abnormal <- tax_table(Colombia_abnormal_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_abnormal) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

ggplot(sigASVs_abnormal, aes(x=Genus, y=log2FoldChange, fill=Phylum)) +
  geom_bar(stat="identity") +
  geom_errorbar(aes(ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  scale_fill_manual(values=my_colors) +
  theme(axis.text.x=element_text(angle=90, hjust=1, vjust=0.5)) +
  scale_y_continuous(limits=c(-8, 8)) + 
  labs(y = "Log2 Fold Change") + labs(title = "Smoker vs Non-smoker Differentially Expressed Genus in the Gut Microbiome (Abnormal)", size = 20)+
  theme(axis.title = element_text(size = 30))

#### Identifying Shared and Unique bacterial ASVs####

names = rbind(sigASVs_abnormal,sigASVs_healthy)
names = unique(names$ASV)

abnormalASV = sigASVs_abnormal$ASV
normalASV = sigASVs_healthy$ASV


# Creating a loop to add the bacterial ASVs to the respective list based on wether they are seen in both healthy and abnormal cardiometabolic status or not
df1 = list()
abnormallist = list()
normallist = list()
for (i in names){
  if (i %in% abnormalASV & i %in% normalASV){
    df1[[i]] = i
    
  } else if(i %in% abnormalASV){
    abnormallist[[i]] = i
    
    
  } else if(i %in% normalASV){
    normallist[[i]] = i
  }
  
  
  
}

# Converting the list to CSV files
taxa_info = data.frame(tax_table(colombia_rare))
taxa_info$ASV = rownames(taxa_info)
df1= data.frame(t(df1))
colnames(df1)[1] = "ASV"
df1$ASV = as.character(df1$ASV)
unique_abnormal_smoking = inner_join(taxa_info, df1, by = "ASV")
write.csv(unique_abnormal_smoking, file = "Shared DESeq ASVs.csv")

abnormallist= data.frame(abnormallist)
colnames(abnormallist)[1] = "ASV"
abnormallist$ASV = as.character(abnormallist$ASV)
unique_abnormal = inner_join(taxa_info, abnormallist, by = "ASV")
write.csv(unique_abnormal, file = "Abnormal unique DESeq ASVs.csv")

normallist= data.frame(t(normallist))
colnames(normallist)[1] = "ASV"
normallist$ASV = as.character(normallist$ASV)
unique_healthy_smoking = inner_join(taxa_info, normallist, by = "ASV")
write.csv(unique_healthy_smoking, file = "Healthy unique DESeq ASVs.csv")